@@ -91,10 +91,11 @@ extern EPS_CMN_FUNC		epsCmnFnc;
 /*******************************************|********************************************/
 static const EPS_UINT16 HufmanDefTable2[] 
 					= {0, 0, 1, 2, 2, 4, 4, 7, 9, 14, 17, 24, 172} ;
-static const EPS_UINT16 HufmanDefTable3[][2] 
+/*static const EPS_UINT16 HufmanDefTable3[][2] 
 					= { 0x00, 2, 0x02, 2, 0x01, 2, 0x03, 4, 0x0b, 4, 
 					    0x07, 5, 0x17, 5, 0x0f, 5, 0x1f, 5,
 					} ;
+*/
 
 /*--------------------------  Private Functions Declaration   --------------------------*/
 /*******************************************|********************************************/
